function f = fallingfloat(m,mw,c,t,w)
%
% The function
%
%   f = fallingfloat(m,mw,c,t,w)
%
% calculates f(m) = sqrt(g(m-mw)/c) tanh( sqrt(gc(m-mw)/m^2)t ) - w(t)
% for the inputs
%         m : mass of the float 
%         mw : mass of seawater
%         c : rho*CD*A/2
%         t : time
%         w : fall velocity
%
f = sqrt(9.81*(m-mw)/c).*tanh( sqrt(9.81*c*(m-mw)./m.^2)*t ) - w;